ChunkedUtf8ValidatorImp

Struct ChunkedUtf8ValidatorImp 

pub struct ChunkedUtf8ValidatorImp {
    algorithm: Utf8CheckAlgorithm<SimdU8Value<__m128i>>,
}
Low-level implementation of the basic::imp::ChunkedUtf8Validator trait.

This is implementation requires CPU SIMD features specified by the module it resides in. It is undefined behavior to call it if the required CPU features are not available.

Fields

algorithm: Utf8CheckAlgorithm<SimdU8Value<__m128i>>