pub struct Utf8ValidatorImp {
algorithm: Utf8CheckAlgorithm<SimdU8Value<__m128i>>,
incomplete_data: [u8; 64],
incomplete_len: usize,
}Expand description
Low-level implementation of the basic::imp::Utf8Validator trait.
This is implementation requires CPU SIMD features specified by the module it resides in. It is undefined behavior to call it if the required CPU features are not available.
Fields
algorithm: Utf8CheckAlgorithm<SimdU8Value<__m128i>>incomplete_data: [u8; 64]incomplete_len: usizeImplementations
Sourceimpl Utf8ValidatorImp
impl Utf8ValidatorImp
unsafe fn update_from_incomplete_data(&mut self)