pub struct ChunkedUtf8ValidatorImp {
algorithm: Utf8CheckAlgorithm<SimdU8Value<__m128i>>,
}Expand description
Low-level implementation of the basic::imp::ChunkedUtf8Validator trait.
This is implementation requires CPU SIMD features specified by the module it resides in. It is undefined behavior to call it if the required CPU features are not available.
Fields
algorithm: Utf8CheckAlgorithm<SimdU8Value<__m128i>>Trait Implementations
Sourceimpl ChunkedUtf8Validator for ChunkedUtf8ValidatorImp
Available on crate feature public_imp only.
impl ChunkedUtf8Validator for ChunkedUtf8ValidatorImp
Available on crate feature
public_imp only.Sourceunsafe fn update_from_chunks(&mut self, input: &[u8])
unsafe fn update_from_chunks(&mut self, input: &[u8])
Updates the validator with
input. Read moreAuto Trait Implementations
impl Freeze for ChunkedUtf8ValidatorImp
impl RefUnwindSafe for ChunkedUtf8ValidatorImp
impl Send for ChunkedUtf8ValidatorImp
impl Sync for ChunkedUtf8ValidatorImp
impl Unpin for ChunkedUtf8ValidatorImp
impl UnsafeUnpin for ChunkedUtf8ValidatorImp
impl UnwindSafe for ChunkedUtf8ValidatorImp